@@ -1,8 +1,8 @@
 'use strict';
 
 var define = require('define-properties');
-var RequireObjectCoercible = require('es-abstract/2019/RequireObjectCoercible');
-var callBound = require('es-abstract/helpers/callBound');
+var RequireObjectCoercible = require('es-abstract/2021/RequireObjectCoercible');
+var callBound = require('call-bind/callBound');
 
 var implementation = require('./implementation');
 var getPolyfill = require('./polyfill');
